==> hs-parsec-3.1.3p0.tgz: lib/ghc/parsec-3.1.3/register.sh <==
#!/bin/sh
echo 'name: parsec
version: 3.1.3
id: parsec-3.1.3-fb970d7908f363dfef34b141200235e6

license: BSD3
copyright:
maintainer: Antoine Latter <aslatter@gmail.com>
stability:
homepage: http://www.cs.uu.nl/~daan/parsec.html
package-url:
synopsis: Monadic parser combinators
description: Parsec is designed from scratch as an industrial-strength parser
             library.  It is simple, safe, well documented (on the package
             homepage), has extensive libraries and good error messages,
             and is also fast.  It is defined as a monad transformer that can be
             stacked on arbitrary monads, and it is also parametric in the
             input stream type.
category: Parsing
author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
pkgpath: devel/hs-parsec
exposed: True
exposed-modules: Text.Parsec Text.Parsec.String
                 Text.Parsec.ByteString Text.Parsec.ByteString.Lazy Text.Parsec.Text
                 Text.Parsec.Text.Lazy Text.Parsec.Pos Text.Parsec.Error
                 Text.Parsec.Prim Text.Parsec.Char Text.Parsec.Combinator
                 Text.Parsec.Token Text.Parsec.Expr Text.Parsec.Language
                 Text.Parsec.Perm Text.ParserCombinators.Parsec
                 Text.ParserCombinators.Parsec.Char
                 Text.ParserCombinators.Parsec.Combinator
                 Text.ParserCombinators.Parsec.Error
                 Text.ParserCombinators.Parsec.Expr
                 Text.ParserCombinators.Parsec.Language
                 Text.ParserCombinators.Parsec.Perm
                 Text.ParserCombinators.Parsec.Pos
                 Text.ParserCombinators.Parsec.Prim
                 Text.ParserCombinators.Parsec.Token
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/parsec-3.1.3
library-dirs: /usr/local/lib/ghc/parsec-3.1.3
hs-libraries: HSparsec-3.1.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
         text-0.11.2.3-6d44323283fc0f3935743a72b4424942
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-parsec-3.1.3/html/parsec.haddock
haddock-html: /usr/local/share/doc/hs-parsec-3.1.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-parsec-3.1.5.tgz: lib/ghc/parsec-3.1.5/register.sh <==
#!/bin/sh
export PATH='/usr/obj/hs-parsec-3.1.5/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: parsec
version: 3.1.5
id: parsec-3.1.5-7f6674da593b27c3fdd904274a0dcd1e

license: BSD3
copyright:
maintainer: Antoine Latter <aslatter@gmail.com>
stability:
homepage: http://www.cs.uu.nl/~daan/parsec.html
package-url:
synopsis: Monadic parser combinators
description: Parsec is designed from scratch as an industrial-strength parser
             library.  It is simple, safe, well documented (on the package
             homepage), has extensive libraries and good error messages,
             and is also fast.  It is defined as a monad transformer that can be
             stacked on arbitrary monads, and it is also parametric in the
             input stream type.
category: Parsing
author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
pkgpath: devel/hs-parsec
exposed: True
exposed-modules: Text.Parsec Text.Parsec.String
                 Text.Parsec.ByteString Text.Parsec.ByteString.Lazy Text.Parsec.Text
                 Text.Parsec.Text.Lazy Text.Parsec.Pos Text.Parsec.Error
                 Text.Parsec.Prim Text.Parsec.Char Text.Parsec.Combinator
                 Text.Parsec.Token Text.Parsec.Expr Text.Parsec.Language
                 Text.Parsec.Perm Text.ParserCombinators.Parsec
                 Text.ParserCombinators.Parsec.Char
                 Text.ParserCombinators.Parsec.Combinator
                 Text.ParserCombinators.Parsec.Error
                 Text.ParserCombinators.Parsec.Expr
                 Text.ParserCombinators.Parsec.Language
                 Text.ParserCombinators.Parsec.Perm
                 Text.ParserCombinators.Parsec.Pos
                 Text.ParserCombinators.Parsec.Prim
                 Text.ParserCombinators.Parsec.Token
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/parsec-3.1.5
library-dirs: /usr/local/lib/ghc/parsec-3.1.5
hs-libraries: HSparsec-3.1.5
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
         text-1.1.0.0-72236c81391c0a9a303f37559690d8fe
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-parsec-3.1.5/html/parsec.haddock
haddock-html: /usr/local/share/doc/hs-parsec-3.1.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
